#include <libint2.h>
#include <GenericContract.h>
#include <OSVRRP0InBra_aB_d__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_d__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_d__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0.h>
#include <OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0.h>

#ifdef __cplusplus
extern "C" {
#endif
void _aB_D__0__K__1___TwoPRep_S__0__D__1___Ab__up_0_prereq(const Libint_t* inteval, LIBINT2_REALTYPE* parent_stack) {

LIBINT2_REALTYPE*const  stack = parent_stack;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+816)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+819)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+822)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+825)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(stack[((hsi*3+822)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_4[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+837)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*6+825)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+847)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+850)*1+lsi)*1]), &(stack[((hsi*3+847)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_3[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+856)*1+lsi)*1]), &(stack[((hsi*6+850)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*3+847)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+819)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+866)*1+lsi)*1]), &(stack[((hsi*3+822)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_5[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+872)*1+lsi)*1]), &(stack[((hsi*6+825)*1+lsi)*1]), &(stack[((hsi*6+866)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(stack[((hsi*3+822)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+882)*1+lsi)*1]), &(stack[((hsi*10+837)*1+lsi)*1]), &(stack[((hsi*10+872)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*6+825)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*10+856)*1+lsi)*1]), &(stack[((hsi*10+837)*1+lsi)*1]), &(stack[((hsi*6+850)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+882)*1+lsi)*1]), &(stack[((hsi*10+856)*1+lsi)*1]), &(stack[((hsi*10+837)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+816)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_6[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+933)*1+lsi)*1]), &(stack[((hsi*6+866)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*3+822)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+943)*1+lsi)*1]), &(stack[((hsi*10+872)*1+lsi)*1]), &(stack[((hsi*10+933)*1+lsi)*1]), &(stack[((hsi*6+825)*1+lsi)*1]), &(stack[((hsi*6+866)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+958)*1+lsi)*1]), &(stack[((hsi*15+882)*1+lsi)*1]), &(stack[((hsi*15+943)*1+lsi)*1]), &(stack[((hsi*10+837)*1+lsi)*1]), &(stack[((hsi*10+872)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+979)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*21+958)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+882)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+837)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+822)*1+lsi)*1]), &(stack[((hsi*3+837)*1+lsi)*1]), &(stack[((hsi*3+847)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_2[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1007)*1+lsi)*1]), &(stack[((hsi*6+822)*1+lsi)*1]), &(stack[((hsi*6+850)*1+lsi)*1]), &(stack[((hsi*3+837)*1+lsi)*1]), &(stack[((hsi*3+847)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1017)*1+lsi)*1]), &(stack[((hsi*10+1007)*1+lsi)*1]), &(stack[((hsi*10+856)*1+lsi)*1]), &(stack[((hsi*6+822)*1+lsi)*1]), &(stack[((hsi*6+850)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1032)*1+lsi)*1]), &(stack[((hsi*15+1017)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*10+1007)*1+lsi)*1]), &(stack[((hsi*10+856)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1053)*1+lsi)*1]), &(stack[((hsi*21+1032)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*15+1017)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]), &(stack[((hsi*21+1032)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+828)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+840)*1+lsi)*1]), &(stack[((hsi*3+828)*1+lsi)*1]), &(stack[((hsi*3+837)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_0[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_1[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+846)*1+lsi)*1]), &(stack[((hsi*6+840)*1+lsi)*1]), &(stack[((hsi*6+822)*1+lsi)*1]), &(stack[((hsi*3+828)*1+lsi)*1]), &(stack[((hsi*3+837)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*10+846)*1+lsi)*1]), &(stack[((hsi*10+1007)*1+lsi)*1]), &(stack[((hsi*6+840)*1+lsi)*1]), &(stack[((hsi*6+822)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+1017)*1+lsi)*1]), &(stack[((hsi*10+846)*1+lsi)*1]), &(stack[((hsi*10+1007)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+837)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*21+1032)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+1017)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1138)*1+lsi)*1]), &(stack[((hsi*28+837)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*21+1032)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1007)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1010)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(stack[((hsi*3+1007)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_7[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1016)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*6+1010)*1+lsi)*1]), &(stack[((hsi*3+819)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*10+933)*1+lsi)*1]), &(stack[((hsi*10+1016)*1+lsi)*1]), &(stack[((hsi*6+866)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*15+943)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*10+872)*1+lsi)*1]), &(stack[((hsi*10+933)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1174)*1+lsi)*1]), &(stack[((hsi*21+958)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*15+882)*1+lsi)*1]), &(stack[((hsi*15+943)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1202)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]), &(stack[((hsi*28+1174)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*21+958)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1238)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*84+1346)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*108+1430)*1+lsi)*1]), &(stack[((hsi*36+1138)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]));
OSVRRP0InBra_aB_d__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*216+1538)*1+lsi)*1]), &(stack[((hsi*108+1430)*1+lsi)*1]), &(stack[((hsi*108+1238)*1+lsi)*1]), &(stack[((hsi*36+1138)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*84+1346)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*216+0)*1+lsi)*1]),&(stack[((hsi*216+1538)*1+lsi)*1]),216);
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1391)*1+lsi)*1]), &(stack[((hsi*36+1138)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*28+837)*1+lsi)*1]), &(stack[((hsi*28+1053)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1436)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1439)*1+lsi)*1]), &(stack[((hsi*3+1007)*1+lsi)*1]), &(stack[((hsi*3+1436)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_8[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1445)*1+lsi)*1]), &(stack[((hsi*6+1010)*1+lsi)*1]), &(stack[((hsi*6+1439)*1+lsi)*1]), &(stack[((hsi*3+816)*1+lsi)*1]), &(stack[((hsi*3+1007)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+816)*1+lsi)*1]), &(stack[((hsi*10+1016)*1+lsi)*1]), &(stack[((hsi*10+1445)*1+lsi)*1]), &(stack[((hsi*6+831)*1+lsi)*1]), &(stack[((hsi*6+1010)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+816)*1+lsi)*1]), &(stack[((hsi*10+933)*1+lsi)*1]), &(stack[((hsi*10+1016)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+1455)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*15+943)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+831)*1+lsi)*1]), &(stack[((hsi*28+1174)*1+lsi)*1]), &(stack[((hsi*28+1455)*1+lsi)*1]), &(stack[((hsi*21+958)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+1483)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]), &(stack[((hsi*36+831)*1+lsi)*1]), &(stack[((hsi*28+979)*1+lsi)*1]), &(stack[((hsi*28+1174)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1754)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*45+1483)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*135+1889)*1+lsi)*1]), &(stack[((hsi*45+1391)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]));
OSVRRP0InBra_aB_d__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*270+2024)*1+lsi)*1]), &(stack[((hsi*135+1889)*1+lsi)*1]), &(stack[((hsi*135+1754)*1+lsi)*1]), &(stack[((hsi*45+1391)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*108+1238)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*270+216)*1+lsi)*1]),&(stack[((hsi*270+2024)*1+lsi)*1]),270);
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1026)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*45+1483)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1889)*1+lsi)*1]), &(stack[((hsi*45+1391)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]), &(stack[((hsi*36+1138)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*3+1238)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_11[vi]));
OSVRRP1InBra_aB_s__0__d__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*6+1241)*1+lsi)*1]), &(stack[((hsi*3+1436)*1+lsi)*1]), &(stack[((hsi*3+1238)*1+lsi)*1]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_9[vi]), &(inteval->_aB_s___0__s___1___TwoPRep_s___0__s___1___Ab__up_10[vi]));
OSVRRP1InBra_aB_s__0__f__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*10+1528)*1+lsi)*1]), &(stack[((hsi*6+1439)*1+lsi)*1]), &(stack[((hsi*6+1241)*1+lsi)*1]), &(stack[((hsi*3+1007)*1+lsi)*1]), &(stack[((hsi*3+1436)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__g__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*15+1238)*1+lsi)*1]), &(stack[((hsi*10+1445)*1+lsi)*1]), &(stack[((hsi*10+1528)*1+lsi)*1]), &(stack[((hsi*6+1010)*1+lsi)*1]), &(stack[((hsi*6+1439)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__h__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*21+1253)*1+lsi)*1]), &(stack[((hsi*15+816)*1+lsi)*1]), &(stack[((hsi*15+1238)*1+lsi)*1]), &(stack[((hsi*10+1016)*1+lsi)*1]), &(stack[((hsi*10+1445)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__i__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*28+933)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]), &(stack[((hsi*21+1253)*1+lsi)*1]), &(stack[((hsi*15+897)*1+lsi)*1]), &(stack[((hsi*15+816)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__k__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*28+1455)*1+lsi)*1]), &(stack[((hsi*28+933)*1+lsi)*1]), &(stack[((hsi*21+1117)*1+lsi)*1]), &(stack[((hsi*21+912)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__l__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*45+867)*1+lsi)*1]), &(stack[((hsi*36+831)*1+lsi)*1]), &(stack[((hsi*36+1081)*1+lsi)*1]), &(stack[((hsi*28+1174)*1+lsi)*1]), &(stack[((hsi*28+1455)*1+lsi)*1]));
OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*55+1081)*1+lsi)*1]), &(stack[((hsi*45+1483)*1+lsi)*1]), &(stack[((hsi*45+867)*1+lsi)*1]), &(stack[((hsi*36+1202)*1+lsi)*1]), &(stack[((hsi*36+831)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+1136)*1+lsi)*1]), &(stack[((hsi*55+1026)*1+lsi)*1]), &(stack[((hsi*55+1081)*1+lsi)*1]), &(stack[((hsi*45+1483)*1+lsi)*1]));
OSVRRP0InBra_aB_p__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*165+816)*1+lsi)*1]), &(stack[((hsi*55+1889)*1+lsi)*1]), &(stack[((hsi*55+1026)*1+lsi)*1]), &(stack[((hsi*45+1346)*1+lsi)*1]));
OSVRRP0InBra_aB_d__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(inteval, &(stack[((hsi*330+2294)*1+lsi)*1]), &(stack[((hsi*165+816)*1+lsi)*1]), &(stack[((hsi*165+1136)*1+lsi)*1]), &(stack[((hsi*55+1889)*1+lsi)*1]), &(stack[((hsi*55+1026)*1+lsi)*1]), &(stack[((hsi*135+1754)*1+lsi)*1]));
_libint2_static_api_inc1_short_(&(stack[((hsi*330+486)*1+lsi)*1]),&(stack[((hsi*330+2294)*1+lsi)*1]),330);
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 816 */
}

#ifdef __cplusplus
};
#endif
